@@ -42,7 +42,7 @@
 #'   logarithmic.
 #' @param yaxis A character string indicating which type of weights
 #'   are to be used. Either \code{"se"}, \code{"invvar"},
-#'   \code{"invse"}, or \code{"size"}.
+#'   \code{"invse"}, code{"size"}, or code{"ess"}.
 #' @param contour.levels A numeric vector specifying contour levels to
 #'   produce contour-enhanced funnel plot.
 #' @param col.contour Colour of contours.
@@ -87,19 +87,23 @@
 #' effects estimate (if \code{comb.random} is TRUE and
 #' \code{comb.fixed} is FALSE).
 #' 
-#' In the funnel plot, if \code{yaxis} is \code{"se"}, the standard
-#' error of the treatment estimates is plotted on the y-axis which is
-#' likely to be the best choice (Sterne & Egger, 2001). Other possible
-#' choices for \code{yaxis} are \code{"invvar"} (inverse of the
-#' variance), \code{"invse"} (inverse of the standard error), and
-#' \code{"size"} (study size).
+#' In the funnel plot, the standard error of the treatment estimates
+#' is plotted on the y-axis by default (\code{yaxis = "se"}) which is
+#' likely to be the best choice (Sterne & Egger, 2001). Only exception
+#' is meta-analysis of diagnostic test accuracy studies (Deeks et al.,
+#' 2005) where the inverse of the square root of the \emph{effective
+#' study size} is used (\code{yaxis = "ess"}). Other possible choices
+#' for \code{yaxis} are \code{"invvar"} (inverse of the variance),
+#' \code{"invse"} (inverse of the standard error), and \code{"size"}
+#' (study size).
 #' 
-#' For \code{yaxis!="size"}, contour-enhanced funnel plots can be
-#' produced (Peters et al., 2008) by specifying the contour levels
-#' (argument \code{contour.levels}). By default (argument
-#' \code{col.contour} missing), suitable gray levels will be used to
-#' distinguish the contours. Different colours can be chosen by
-#' argument \code{col.contour}.
+#' If argument \code{yaxis} is not equal to \code{"size"} or
+#' \code{"ess"}, contour-enhanced funnel plots can be produced (Peters
+#' et al., 2008) by specifying the contour levels (argument
+#' \code{contour.levels}). By default (argument \code{col.contour}
+#' missing), suitable gray levels will be used to distinguish the
+#' contours. Different colours can be chosen by argument
+#' \code{col.contour}.
 #' 
 #' @author Guido Schwarzer \email{sc@@imbi.uni-freiburg.de}, Petra
 #'   Graham \email{pgraham@@efs.mq.edu.au}
@@ -108,6 +112,13 @@
 #'   \code{\link{metagen}}, \code{\link{radial}}
 #' 
 #' @references
+#' Deeks JJ, Macaskill P, Irwig L (2005):
+#' The performance of tests of publication bias and other sample size
+#' effects in systematic reviews of diagnostic test accuracy was
+#' assessed.
+#' \emph{Journal of Clinical Epidemiology},
+#' \bold{58}:882--93
+#'
 #' Light RJ & Pillemer DB (1984):
 #' \emph{Summing Up. The Science of Reviewing Research}.
 #' Cambridge: Harvard University Press
@@ -179,7 +190,7 @@ funnel.meta <- function(x,
                         col = "black", bg = "darkgray",
                         col.fixed = "black", col.random = "black",
                         ##
-                        log, yaxis = "se",
+                        log, yaxis,
                         contour.levels = NULL, col.contour,
                         ##
                         ref = ifelse(is.relative.effect(x$sm), 1, 0),
@@ -228,7 +239,14 @@ funnel.meta <- function(x,
   chknumeric(lwd)
   chknumeric(lwd.fixed)
   chknumeric(lwd.random)
+  ##
+  if (missing(yaxis))
+    if (inherits(x, "metabin") && x$sm == "DOR")
+      yaxis <- "ess"
+    else
+      yaxis <- "se"
   yaxis <- setchar(yaxis, c("se", "size", "invvar", "invse", "ess"))
+  ##
   if (!is.null(contour.levels))
     chklevel(contour.levels, length = 0, ci = FALSE)
   chknumeric(ref)
@@ -408,7 +426,8 @@ funnel.meta <- function(x,
   if (yaxis == "invse"  & is.null(ylab)) ylab <- "Inverse of Standard Error"
   if (yaxis == "ess"    & is.null(ylab)) ylab <- "1 / root(Effective Study Size)"
   ##
-  if (is.null(ylim) & yaxis == "se") ylim <- c(max(weight, na.rm = TRUE), 0)
+  if (is.null(ylim) & yaxis %in% c("se", "ess"))
+    ylim <- c(max(weight, na.rm = TRUE), 0)
   if (is.null(ylim)) ylim <- range(weight, na.rm = TRUE)
   
   
@@ -621,13 +640,13 @@ funnel.meta <- function(x,
   
   ##
   ##
-  ## (6) Return contour levels (if not NULL)
+  ## (6) Return some information on funnel plot
   ##
   ##
+  res <- list(xlim = xlim, ylim = ylim)
+  ##
   if (!is.null(contour.levels) & yaxis != "size")
-    res <- list(col.contour = col.contour)
-  else
-    res <- NULL
+    res$col.contour <- col.contour
   
   
   invisible(res)
